%global _hardened_build 1

Name:           oreon-installer
Version:        10.0
Release:        1%{?dist}
Summary:        Distribution-independent installer framework for Oreon Linux

License:        BSD-2-Clause AND GPL-3.0-or-later AND CC0-1.0
URL:            https://oreonproject.org/
Source0:        %{name}-%{version}.tar.gz

BuildRequires:  cmake >= 3.16.0
BuildRequires:  gcc-c++
BuildRequires:  extra-cmake-modules >= 6
BuildRequires:  kf6-kcoreaddons-devel
BuildRequires:  kf6-kcrash-devel
BuildRequires:  qt6-qtbase-devel >= 6.6
BuildRequires:  qt6-qttools-devel
BuildRequires:  qt6-qtsvg-devel
BuildRequires:  qt6-qtdeclarative-devel
BuildRequires:  yaml-cpp-devel >= 0.5.1
BuildRequires:  python3-devel >= 3.6
BuildRequires:  pybind11-devel
BuildRequires:  boost-devel
BuildRequires:  boost-python3-devel
BuildRequires:  polkit-qt6-1-devel
BuildRequires:  desktop-file-utils
BuildRequires:  libappstream-glib

Requires:       qt6-qtbase >= 6.6
Requires:       qt6-qtsvg
Requires:       qt6-qtdeclarative
Requires:       kf6-kcoreaddons
Requires:       yaml-cpp >= 0.5.1
Requires:       python3 >= 3.6
Requires:       polkit
Requires:       udisks2
Requires:       parted
Requires:       e2fsprogs
Requires:       dosfstools
Requires:       ntfs-3g
Requires:       rsync
Requires:       squashfs-tools
Requires:       util-linux
Requires:       coreutils
Requires:       systemd
Requires:       NetworkManager

%description
Calamares is a distribution-independent system installer with an advanced
partitioning framework. This package ships the Oreon-branded Calamares build
used by Oreon Linux distributions.

%prep
%autosetup -n %{name}-%{version}

%build
%cmake \
  -DCMAKE_BUILD_TYPE=RelWithDebInfo \
  -DWITH_QT6=ON \
  -DWITH_QML=ON \
  -DWITH_PYTHON=ON \
  -DWITH_PYBIND11=ON \
  -DINSTALL_POLKIT=ON \
  -DINSTALL_CONFIG=OFF \
  -DINSTALL_COMPLETION=OFF \
  -DBUILD_TESTING=OFF \
  -DBUILD_CRASH_REPORTING=ON \
  -DBUILD_SCHEMA_TESTING=OFF \
  -DSKIP_MODULES="dracut;initramfscfg"

%cmake_build

%install
%cmake_install

# desktop entry (may be absent in headless builds)
if [ -f %{buildroot}%{_datadir}/applications/calamares.desktop ]; then
  desktop-file-install \
    --dir=%{buildroot}%{_datadir}/applications \
    --delete-original \
    %{buildroot}%{_datadir}/applications/calamares.desktop
fi

# binary perms
[ -f %{buildroot}%{_bindir}/calamares ] && chmod 0755 %{buildroot}%{_bindir}/calamares

# config dirs
mkdir -p %{buildroot}%{_sysconfdir}/calamares/{modules,branding}

%files
%license LICENSES/*
%doc AUTHORS CHANGES-3.2 README.md
%{_bindir}/calamares
%{_libdir}/libcalamares.so.*
%{_libdir}/libcalamaresui.so.*
%{_libdir}/calamares/
%{_datadir}/calamares/
%{_datadir}/applications/calamares.desktop
%{_datadir}/polkit-1/actions/com.github.calamares.calamares.policy
%{_mandir}/man8/calamares.8*
%dir %{_sysconfdir}/calamares
%dir %{_sysconfdir}/calamares/modules
%dir %{_sysconfdir}/calamares/branding

%post   -p /sbin/ldconfig
/usr/bin/update-desktop-database &>/dev/null || :

%postun -p /sbin/ldconfig
/usr/bin/update-desktop-database &>/dev/null || :

%changelog
* Sun Jul 13 2025 Brandon Lester <blester@oreonproject.org> 10.0-1
- Switch build to Qt 6 / KF6
- Drop obsolete Qt 5 and KF5 BRs
- Use libappstream-glib rather than appstream-glib
- Fix SKIP_MODULES delimiter and misc build-flags
